@@ -3,6 +3,7 @@ package DateTime::Format::Natural;
 use strict;
 use warnings;
 use base qw(DateTime::Format::Natural::Base);
+use boolean qw(true false);
 
 use Carp qw(croak);
 use DateTime ();
@@ -10,7 +11,7 @@ use Date::Calc qw(Day_of_Week check_date);
 use List::MoreUtils qw(all any);
 use Params::Validate ':all';
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 validation_options(
     on_fail => sub
@@ -40,7 +41,7 @@ sub _init
 
     $self->{Format}        = $opts{format}        || 'd/m/y';
     $self->{Lang}          = $opts{lang}          || 'en';
-    $self->{Prefer_future} = $opts{prefer_future} || 0;
+    $self->{Prefer_future} = $opts{prefer_future} || false;
     $self->{Time_zone}     = $opts{time_zone}     || 'floating';
     $self->{Opts}{daytime} = $opts{daytime};
 
@@ -58,22 +59,22 @@ sub _init_check
     validate(@_, {
         lang => {
             type => SCALAR,
-            optional => 1,
+            optional => true,
             regex => qr!^(?:en)$!,
         },
         format => {
             type => SCALAR,
-            optional => 1,
+            optional => true,
             regex => qr!^(?:[dmy]{1,4}[-./]){2}[dmy]{1,4}$!i,
         },
         prefer_future => {
-            type => SCALAR,
-            optional => 1,
-            regex => qr!^[01]$!,
+            # SCALARREF due to boolean.pm's implementation
+            type => BOOLEAN | SCALARREF,
+            optional => true,
         },
         time_zone => {
             type => SCALAR,
-            optional => 1,
+            optional => true,
             callbacks => {
                 'valid timezone' => sub
                 {
@@ -84,7 +85,7 @@ sub _init_check
         },
         daytime => {
             type => HASHREF,
-            optional => 1,
+            optional => true,
         },
     });
 }
@@ -164,9 +165,11 @@ sub parse_datetime
             return $self->_get_datetime_object;
         }
 
-        $self->{datetime}->set_year($year);
-        $self->{datetime}->set_month($month);
-        $self->{datetime}->set_day($day);
+        $self->{datetime}->set(
+            year  => $year,
+            month => $month,
+            day   => $day,
+        );
 
         $self->_set_valid_exp;
         $self->_set_modified(1);
@@ -240,7 +243,7 @@ sub success
 {
     my $self = shift;
 
-    return ($self->_get_valid_exp && !$self->_get_failure) ? 1 : 0;
+    return ($self->_get_valid_exp && !$self->_get_failure) ? true : false;
 }
 
 sub error
@@ -279,7 +282,7 @@ sub _process
         last if $self->_get_modified >= @{$self->{tokens}};
 
         foreach my $expression (@grammar) {
-            my $valid_expression = 1;
+            my $valid_expression = true;
             my $definition = $expression->[0];
             my @positions = keys %$definition;
             my %regex_stack;
@@ -290,7 +293,7 @@ sub _process
                             next;
                         }
                         else {
-                            $valid_expression = 0;
+                            $valid_expression = false;
                         }
                     }
                 }
@@ -301,7 +304,7 @@ sub _process
                         next;
                     }
                     else {
-                        $valid_expression = 0;
+                        $valid_expression = false;
                     }
                 }
                 else {
@@ -313,9 +316,9 @@ sub _process
                 $self->_set_valid_exp;
                 my $i;
                 foreach my $positions (@{$expression->[1]}) {
-                    my @values;
+                    my ($c, @values);
                     foreach my $pos (@$positions) {
-                        $values[$pos] = exists $regex_stack{$pos}
+                        $values[$c++] = exists $regex_stack{$pos}
                           ? $regex_stack{$pos}
                           : ${$self->_token($pos)};
                     }
@@ -336,7 +339,7 @@ sub _post_process_options
     my $self = shift;
 
     if ($self->{Prefer_future}) {
-        my %modified = map { $_ => 1 } grep { $_ ne 'total' } keys %{$self->{modified}};
+        my %modified = map { $_ => true } grep { $_ ne 'total' } keys %{$self->{modified}};
 
         if ($self->{count}{tokens} == 1
             && (any { $self->{tokens}->[0] =~ /$_/i } @{$self->{data}->{weekdays_all}})
@@ -352,8 +355,8 @@ sub _post_process_options
             && (exists $self->{modified}{month} && $self->{modified}{month} == 1)
             && (exists $self->{modified}{day}
                   ? $self->{modified}{day} == 1
-                    ? 1 : 0
-                  : 1)
+                    ? true : false
+                  : true)
             && ($self->{datetime}->day_of_year < DateTime->now->day_of_year)
         ) {
             $self->{postprocess}{year} = 1;
@@ -380,13 +383,13 @@ sub _get_error       { $_[0]->{error}         }
 sub _set_error       { $_[0]->{error} = $_[1] }
 sub _unset_error     { $_[0]->{error} = ''    }
 
-sub _get_failure     { $_[0]->{failure}     }
-sub _set_failure     { $_[0]->{failure} = 1 }
-sub _unset_failure   { $_[0]->{failure} = 0 }
+sub _get_failure     { $_[0]->{failure}         }
+sub _set_failure     { $_[0]->{failure} = true  }
+sub _unset_failure   { $_[0]->{failure} = false }
 
-sub _get_valid_exp   { $_[0]->{valid_expression}     }
-sub _set_valid_exp   { $_[0]->{valid_expression} = 1 }
-sub _unset_valid_exp { $_[0]->{valid_expression} = 0 }
+sub _get_valid_exp   { $_[0]->{valid_expression}         }
+sub _set_valid_exp   { $_[0]->{valid_expression} = true  }
+sub _unset_valid_exp { $_[0]->{valid_expression} = false }
 
 sub _get_modified    { $_[0]->{modified}{total} || 0     }
 sub _set_modified    { $_[0]->{modified}{total} += $_[1] }
@@ -437,7 +440,7 @@ sub _set_datetime
                                       hour      => $hour,
                                       minute    => $min,
                                       second    => $sec);
-    $self->{running_tests} = 1;
+    $self->{running_tests} = true;
 }
 
 1;
@@ -505,7 +508,7 @@ Specifies the format of numeric dates, defaults to 'C<d/m/y>'.
 =item * C<prefer_future>
 
 Turns ambigious weekdays/months to their futuristic relatives. Accepts a boolean,
-defaults to 0.
+defaults to false.
 
 =item * C<time_zone>
 
@@ -597,6 +600,7 @@ valuable suggestions & patches:
  Jesse Vincent
  Jason May
  Pat Kale
+ Ankur Gupta
 
 =head1 SEE ALSO
 
